@@ -19,8 +19,10 @@ class Configuration(object):
 
 conf = Configuration(
     SECURE_HSTS_SECONDS=0,
+    SECURE_HSTS_INCLUDE_SUBDOMAINS=False,
     SECURE_FRAME_DENY=False,
     SECURE_CONTENT_TYPE_NOSNIFF=False,
+    SECURE_BROWSER_XSS_FILTER=False,
     SECURE_SSL_REDIRECT=False,
     SECURE_SSL_HOST=None,
     SECURE_REDIRECT_EXEMPT=[],
@@ -31,8 +33,10 @@ conf = Configuration(
         "djangosecure.check.sessions.check_session_cookie_httponly",
         "djangosecure.check.djangosecure.check_security_middleware",
         "djangosecure.check.djangosecure.check_sts",
+        "djangosecure.check.djangosecure.check_sts_include_subdomains",
         "djangosecure.check.djangosecure.check_frame_deny",
         "djangosecure.check.djangosecure.check_content_type_nosniff",
+        "djangosecure.check.djangosecure.check_xss_filter",
         "djangosecure.check.djangosecure.check_ssl_redirect",
         ]
     )
