@@ -144,6 +144,35 @@ class SecurityMiddlewareTest(TestCase):
             "strict-transport-security" in self.process_response(secure=True))
 
 
+    @override_settings(
+        SECURE_HSTS_SECONDS=600, SECURE_HSTS_INCLUDE_SUBDOMAINS=True)
+    def test_sts_include_subdomains(self):
+        """
+        With SECURE_HSTS_SECONDS non-zero and SECURE_HSTS_INCLUDE_SUBDOMAINS
+        True, the middleware adds a "strict-transport-security" header with the
+        "includeSubDomains" tag to the response.
+
+        """
+        response = self.process_response(secure=True)
+        self.assertEqual(
+            response["strict-transport-security"],
+            "max-age=600; includeSubDomains",
+            )
+
+
+    @override_settings(
+        SECURE_HSTS_SECONDS=600, SECURE_HSTS_INCLUDE_SUBDOMAINS=False)
+    def test_sts_no_include_subdomains(self):
+        """
+        With SECURE_HSTS_SECONDS non-zero and SECURE_HSTS_INCLUDE_SUBDOMAINS
+        False, the middleware adds a "strict-transport-security" header without
+        the "includeSubDomains" tag to the response.
+
+        """
+        response = self.process_response(secure=True)
+        self.assertEqual(response["strict-transport-security"], "max-age=600")
+
+
     @override_settings(SECURE_CONTENT_TYPE_NOSNIFF=True)
     def test_content_type_on(self):
         """
@@ -179,6 +208,41 @@ class SecurityMiddlewareTest(TestCase):
         self.assertFalse("x-content-type-options" in self.process_response())
 
 
+    @override_settings(SECURE_BROWSER_XSS_FILTER=True)
+    def test_xss_filter_on(self):
+        """
+        With SECURE_BROWSER_XSS_FILTER set to True, the middleware adds
+        "s-xss-protection: 1; mode=block" header to the response.
+
+        """
+        self.assertEqual(
+            self.process_response()["x-xss-protection"],
+            "1; mode=block")
+
+
+    @override_settings(SECURE_BROWSER_XSS_FILTER=True)
+    def test_xss_filter_already_present(self):
+        """
+        The middleware will not override an "x-xss-protection" header
+        already present in the response.
+
+        """
+        response = self.process_response(
+            secure=True,
+            headers={"x-xss-protection": "foo"})
+        self.assertEqual(response["x-xss-protection"], "foo")
+
+
+    @override_settings(SECURE_BROWSER_XSS_FILTER=False)
+    def test_xss_filter_off(self):
+        """
+        With SECURE_BROWSER_XSS_FILTER set to False, the middleware does not add an
+        "x-xss-protection" header to the response.
+
+        """
+        self.assertFalse("x-xss-protection" in self.process_response())
+
+
     @override_settings(SECURE_SSL_REDIRECT=True)
     def test_ssl_redirect_on(self):
         """
@@ -562,6 +626,25 @@ class CheckStrictTransportSecurityTest(TestCase):
 
 
 
+class CheckStrictTransportSecuritySubdomainsTest(TestCase):
+    @property
+    def func(self):
+        from djangosecure.check.djangosecure import check_sts_include_subdomains
+        return check_sts_include_subdomains
+
+
+    @override_settings(SECURE_HSTS_INCLUDE_SUBDOMAINS=False)
+    def test_no_sts_subdomains(self):
+        self.assertEqual(
+            self.func(), set(["STRICT_TRANSPORT_SECURITY_NO_SUBDOMAINS"]))
+
+
+    @override_settings(SECURE_HSTS_INCLUDE_SUBDOMAINS=True)
+    def test_with_sts_subdomains(self):
+        self.assertEqual(self.func(), set())
+
+
+
 class CheckFrameDenyTest(TestCase):
     @property
     def func(self):
@@ -600,6 +683,25 @@ class CheckContentTypeNosniffTest(TestCase):
 
 
 
+class CheckXssFilterTest(TestCase):
+    @property
+    def func(self):
+        from djangosecure.check.djangosecure import check_xss_filter
+        return check_xss_filter
+
+
+    @override_settings(SECURE_BROWSER_XSS_FILTER=False)
+    def test_no_xss_filter(self):
+        self.assertEqual(
+            self.func(), set(["BROWSER_XSS_FILTER_NOT_ENABLED"]))
+
+
+    @override_settings(SECURE_BROWSER_XSS_FILTER=True)
+    def test_with_xss_filter(self):
+        self.assertEqual(self.func(), set())
+
+
+
 class CheckSSLRedirectTest(TestCase):
     @property
     def func(self):
@@ -643,13 +745,17 @@ class ConfTest(TestCase):
                     "djangosecure.check.sessions.check_session_cookie_httponly",
                     "djangosecure.check.djangosecure.check_security_middleware",
                     "djangosecure.check.djangosecure.check_sts",
+                    "djangosecure.check.djangosecure.check_sts_include_subdomains",
                     "djangosecure.check.djangosecure.check_frame_deny",
                     "djangosecure.check.djangosecure.check_content_type_nosniff",
+                    "djangosecure.check.djangosecure.check_xss_filter",
                     "djangosecure.check.djangosecure.check_ssl_redirect",
                     ],
                 "SECURE_HSTS_SECONDS": 0,
+                "SECURE_HSTS_INCLUDE_SUBDOMAINS": False,
                 "SECURE_FRAME_DENY": False,
                 "SECURE_CONTENT_TYPE_NOSNIFF": False,
+                "SECURE_BROWSER_XSS_FILTER": False,
                 "SECURE_SSL_REDIRECT": False,
                 "SECURE_SSL_HOST": None,
                 "SECURE_REDIRECT_EXEMPT": [],
